@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -36,17 +36,13 @@ class KPIM::CompletionConfigureDialogPrivate
 {
 public:
     CompletionConfigureDialogPrivate()
-        : mTabWidget(nullptr)
-        , mCompletionOrderWidget(nullptr)
-        , mBlackListBalooWidget(nullptr)
-        , mRecentaddressWidget(nullptr)
     {
     }
 
-    QTabWidget *mTabWidget;
-    KPIM::CompletionOrderWidget *mCompletionOrderWidget;
-    KPIM::BlackListBalooEmailCompletionWidget *mBlackListBalooWidget;
-    KPIM::RecentAddressWidget *mRecentaddressWidget;
+    QTabWidget *mTabWidget = nullptr;
+    KPIM::CompletionOrderWidget *mCompletionOrderWidget = nullptr;
+    KPIM::BlackListBalooEmailCompletionWidget *mBlackListBalooWidget = nullptr;
+    KPIM::RecentAddressWidget *mRecentaddressWidget = nullptr;
 };
 
 CompletionConfigureDialog::CompletionConfigureDialog(QWidget *parent)
